@@ -13,7 +13,7 @@ import urllib.parse
 
 import jinja2
 from bs4 import BeautifulSoup
-from zimscraperlib.zim import ZimInfo, make_zim_file
+from zimscraperlib.zim import make_zim_file
 from zimscraperlib.i18n import get_language_details
 from zimscraperlib.download import save_large_file
 from zimscraperlib.video.presets import VideoWebmLow, VideoMp4Low
@@ -105,17 +105,6 @@ class Ted2Zim:
             )
         )
 
-        # zim info
-        self.zim_info = ZimInfo(
-            homepage="index.html",
-            tags=self.tags + ["_category:ted", "ted", "_videos:yes"],
-            creator=self.creator,
-            publisher=self.publisher,
-            name=self.name,
-            scraper=SCRAPER,
-            favicon="favicon.png",
-        )
-
         # optimization cache
         self.s3_url_with_credentials = s3_url_with_credentials
         self.use_any_optimized_version = use_any_optimized_version
@@ -520,7 +509,7 @@ class Ted2Zim:
             speaker_info = {
                 "description": "None",
                 "whotheyare": "None",
-                "photo_url": "None",
+                "photo_url": "",
             }
             if "speaker_name" in talk_info:
                 speaker = talk_info["speaker_name"]
@@ -761,7 +750,7 @@ class Ted2Zim:
                     logger.error(f"Could not download {org_video_file_path}")
 
             # download an image of the speaker
-            if video_speaker == "None" or video_speaker == "":
+            if not video_speaker:
                 logger.debug("Speaker doesn't have an image")
             else:
                 logger.debug(f"Downloading Speaker image for {video_title}")
@@ -923,13 +912,22 @@ class Ted2Zim:
                 self.fname or f"{self.name.replace(' ', '-')}_{{period}}.zim"
             ).format(period=datetime.datetime.now().strftime("%Y-%m"))
             logger.info("building ZIM file")
-            self.zim_info.update(
-                title=self.title, description=self.description, language=self.zim_lang
-            )
-            logger.debug(self.zim_info.to_zimwriterfs_args())
             if not self.output_dir.exists():
                 self.output_dir.mkdir(parents=True)
-            make_zim_file(self.build_dir, self.output_dir, self.fname, self.zim_info)
+            make_zim_file(
+                build_dir=self.build_dir,
+                fpath=self.output_dir.joinpath(self.fname),
+                name=self.name,
+                main_page="index.html",
+                favicon="favicon.png",
+                title=self.title,
+                description=self.description,
+                language=self.zim_lang,
+                creator=self.creator,
+                publisher=self.publisher,
+                tags=self.tags + ["_category:ted", "ted", "_videos:yes"],
+                scraper=SCRAPER,
+            )
             if not self.keep_build_dir:
                 logger.info("removing temp folder")
                 shutil.rmtree(self.build_dir, ignore_errors=True)
